==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/ps.pl <==
{
  am_pm_abbreviated => [
    "\N{U+063a}.\N{U+0645}.",
    "\N{U+063a}.\N{U+0648}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMM",
    "MMMMW-count-other" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} w \N{U+062f} Y",
    "yw-count-other" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} w \N{U+062f} Y",
  },
  code => "ps",
  date_format_full => "EEEE \N{U+062f} y \N{U+062f} MMMM d",
  date_format_long => "\N{U+062f} y \N{U+062f} MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  era_abbreviated => [
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0648}\N{U+0693}\N{U+0627}\N{U+0646}\N{U+062f}\N{U+06d0}",
    "\N{U+0645}.",
  ],
  era_narrow => [
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0648}\N{U+0693}\N{U+0627}\N{U+0646}\N{U+062f}\N{U+06d0}",
    "\N{U+0645}.",
  ],
  era_wide => [
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0685}\N{U+062e}\N{U+0647} \N{U+0648}\N{U+0693}\N{U+0627}\N{U+0646}\N{U+062f}\N{U+06d0}",
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0685}\N{U+062e}\N{U+0647} \N{U+0648}\N{U+0631}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0647}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Pashto",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+06d0}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    "\N{U+062c}",
    "\N{U+0641}",
    "\N{U+0645}",
    "\N{U+0627}",
    "\N{U+0645}",
    "\N{U+062c}",
    "\N{U+062c}",
    "\N{U+0627}",
    "\N{U+0633}",
    "\N{U+0627}",
    "\N{U+0646}",
    "\N{U+062f}",
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+06d0}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+06d0}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Pashto",
  native_language => "\N{U+067e}\N{U+069a}\N{U+062a}\N{U+0648}",
  native_name => "\N{U+067e}\N{U+069a}\N{U+062a}\N{U+0648}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H:mm:ss (zzzz)",
  time_format_long => "H:mm:ss (z)",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/ps.pl <==
{
  am_pm_abbreviated => [
    "\N{U+063a}.\N{U+0645}.",
    "\N{U+063a}.\N{U+0648}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}\N{U+2018} W \N{U+062f} MMMM\N{U+2018}",
    "MMMMW-count-other" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} W \N{U+062f} MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} w \N{U+062f} Y",
    "yw-count-other" => "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd} w \N{U+062f} Y",
  },
  code => "ps",
  date_format_full => "EEEE \N{U+062f} y \N{U+062f} MMMM d",
  date_format_long => "\N{U+062f} y \N{U+062f} MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+062f}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+062f}\N{U+0631}\N{U+06d0}\N{U+0646}\N{U+06cd}",
    "\N{U+0685}\N{U+0644}\N{U+0631}\N{U+0646}\N{U+06cd}",
    "\N{U+067e}\N{U+064a}\N{U+0646}\N{U+0681}\N{U+0646}\N{U+06cd}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0647}",
    "\N{U+0627}\N{U+0648}\N{U+0646}\N{U+06cd}",
    "\N{U+064a}\N{U+0648}\N{U+0646}\N{U+06cd}",
  ],
  era_abbreviated => [
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0648}\N{U+0693}\N{U+0627}\N{U+0646}\N{U+062f}\N{U+06d0}",
    "\N{U+0645}.",
  ],
  era_narrow => [
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0648}\N{U+0693}\N{U+0627}\N{U+0646}\N{U+062f}\N{U+06d0}",
    "\N{U+0645}.",
  ],
  era_wide => [
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0685}\N{U+062e}\N{U+0647} \N{U+0648}\N{U+0693}\N{U+0627}\N{U+0646}\N{U+062f}\N{U+06d0}",
    "\N{U+0644}\N{U+0647} \N{U+0645}\N{U+06cc}\N{U+0644}\N{U+0627}\N{U+062f} \N{U+0685}\N{U+062e}\N{U+0647} \N{U+0648}\N{U+0631}\N{U+0648}\N{U+0633}\N{U+062a}\N{U+0647}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Pashto",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06ab}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+06d0}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    "\N{U+062c}",
    "\N{U+0641}",
    "\N{U+0645}",
    "\N{U+0627}",
    "\N{U+0645}",
    "\N{U+062c}",
    "\N{U+062c}",
    "\N{U+0627}",
    "\N{U+0633}",
    "\N{U+0627}",
    "\N{U+0646}",
    "\N{U+062f}",
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06ab}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+06d0}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06ab}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0641}\N{U+06d0}\N{U+0628}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+064a}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+06cd}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+06cc}",
    "\N{U+0627}\N{U+06ab}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+067e}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Pashto",
  native_language => "\N{U+067e}\N{U+069a}\N{U+062a}\N{U+0648}",
  native_name => "\N{U+067e}\N{U+069a}\N{U+062a}\N{U+0648}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0644}\N{U+0648}\N{U+0645}\N{U+0693}\N{U+06cd} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f2}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f3}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
    "\N{U+06f4}\N{U+0645}\N{U+0647} \N{U+0631}\N{U+0628}\N{U+0639}\N{U+0647}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H:mm:ss (zzzz)",
  time_format_long => "H:mm:ss (z)",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 42,
}
